mix chromic_pdf.warm_up (ChromicPDF v1.17.1)

Runs a one-off Chrome process to allow Chrome to initialize its caches.

This function mitigates timeout errors on certain CI environments where Chrome would occasionally take a long time to respond to the first DevTools commands.

See ChromicPDF.warm_up/1 for details.